//usmReader

#include <Wire.h> //I2Cライブラリのヘッダ

#define I2C_ADRS 0x29 //超音波距離計のアドレス
#define I2C_LAD 15 //閾値の初期値
#define I2C_NOISE 6 //雑音レベル

byte lad; //閾値

void setup(){
	lad = I2C_LAD; //閾値の初期値を設定
	Wire.begin(); //I2Cをマスタの立場に初期化
	Serial.begin(9600); //非同期シリアルを通信速度9600bpsで初期化
}

//閾値を変更する関数
void usmChangeLad(){
	//閾値の変更
	Wire.beginTransmission(I2C_ADRS); //I2Cの書き込みを開始
	Wire.write(lad); //閾値を書き込む
	Wire.endTransmission(); //I2Cの書き込みを終了

	//変更の表示
	Serial.print("Threshold changed to "); //見出しを表示
	Serial.print(3.3 * lad / 31); //閾値を表示
	Serial.println("V"); //単位を表示して改行
}

void loop(){
	int distance; //距離

	//距離の取得
	Wire.requestFrom(I2C_ADRS, 2); //I2Cで2バイトを読み込む
	distance = //距離を計算
		((int)Wire.read() << 8) | Wire.read();

	//下限の処理
	if(distance == -2){ //もし近すぎるエラーなら
		Serial.print("Near: "); //近すぎると表示
		if(lad < 31){ //もし閾値が上限でなければ
			lad++; //閾値を上げる
			usmChangeLad(); //閾値を書き込む
		} else //そうでなければ（閾値が上限なら）
			Serial.println("Limit"); //ここが限界と表示
	}
	//上限の処理
	else //そう（近すぎるエラー）でなければ
	if(distance == -1){ //もし遠すぎるエラーなら
		Serial.print("Far: "); //遠すぎると表示
		if(lad > I2C_NOISE){ //もし閾値が下限（雑音レベル）でなければ
			lad--; //閾値を下げる
			usmChangeLad(); //閾値を書き込む
		} else //そうでなければ（閾値が下限なら）
			Serial.println("Limit."); //ここが限界と表示
	}
	//正常に測定した場合の処理
	else { //そう（エラー）でなければ
		Serial.print("Distance: "); //見出しを表示
		Serial.print(distance); //距離を表示
		Serial.println("mm"); //単位を表示して改行
	}

  delay(1000); //1秒停止
}
